/*
 * @(#)src/classes/sov/java/nio/channels/spi/AbstractSelectionKey.java, nio, as142, 20090306 1.7.2.2
 * ===========================================================================
 * IBM Confidential
 * OCO Source Materials
 *
 * IBM SDK, Java(tm) 2 Technology Edition, v1.4.2
 * (C) Copyright IBM Corp. 1998, 2004.
 *
 * The source code for this program is not published or otherwise divested of
 * its trade secrets, irrespective of what has been deposited with the U.S.
 * Copyright office.
 * ===========================================================================
 */

/*
 * ===========================================================================
 * Copyright 2003 Sun Microsystems, Inc. All rights reserved.
 * ===========================================================================
 */

/*
 * Change activity:
 *
 * Reason  Date    Origin    Description
 * ------  ------  --------  --------------------------------------------------
 * 143196  131108  pkannojo  Port changes from 104278, Make cancel() atomic
 */



package java.nio.channels.spi;

import java.nio.channels.*;


/**
 * Base implementation class for selection keys.
 *
 * <p> This class tracks the validity of the key and implements cancellation.
 *
 * @author Mark Reinhold
 * @author JSR-51 Expert Group
 * @version 1.8, 01/12/03
 * @since 1.4
 */

public abstract class AbstractSelectionKey
    extends SelectionKey
{

    /**
     * Initializes a new instance of this class.  </p>
     */
    protected AbstractSelectionKey() { }

    private volatile boolean valid = true;

    public final boolean isValid() {
        return valid;
    }

    private final Object cancelLock = new Object();             /*ibm@143196*/

    /**
     * Cancels this key.
     *
     * <p> If this key has not yet been cancelled then it is added to its
     * selector's cancelled-key set.  </p>
     */
    public final void cancel() {
        /*ibm@143196 - Port changes as per 104278. In order to make cancel()
        * atomic, the fix for Sun bug 4744057 synchronizes on "this", which
        * conflicts with our fix for 60554. We synchronize on something
        * else to avoid deadlocking with the fix for 60554.
        */
        synchronized(cancelLock) {                              /*ibm@143196*/
            if (valid) {
                valid = false;
                ((AbstractSelector)selector()).cancel(this);
            }
        }                                                       /*ibm@143196*/
    }
}
